import { r as registerInstance, e as createEvent, h, f as Host } from './index-570f8c12.js';

const jiraIssuesCss = ":host{display:block}";

const JiraIssues = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.issueSelected = createEvent(this, "issueSelected", 7);
    this.issues = [];
  }
  /*
  {
      "self": string,
      "key": string,
      "account_id": string,
      "accountType": string,
      "name": string,
      "avatarUrls": {
        "48x48": string,
        "24x24": string,
        "16x16": string,
        "32x32": string
      },
      "displayName": string,
      "active": boolean
    }
  }*/
  componentWillLoad() {
    return this.loadData();
    /**
     * .then(a => {
      console.log(a);
    }).catch(b => {
      console.error(b);
    }).finally(() => {
      console.info('finished', this.endpoint);
    })
     */
  }
  watchAccountHandler(newValue, oldValue) {
    console.log('The new value of account_id is: ', newValue, oldValue);
    this.loadData();
  }
  watchStatusHandler(newValue, oldValue) {
    console.log('The new value of status is: ', newValue, oldValue);
    this.loadData();
  }
  loadData() {
    const requestHeaders = new Headers();
    requestHeaders.set('Content-Type', 'application/json');
    //requestHeaders.set('Authorization', 'Bearer ' + btoa(unescape(encodeURIComponent(`${this.email}:${this.apitoken}`))))
    //https://bawes.atlassian.net/rest/api/3/users/search
    let url = this.endpoint + '/jira/issues?';
    if (this.account_id)
      url += 'accountId=' + this.account_id;
    if (this.status)
      url += '&status=' + this.status;
    return fetch(url, {
      headers: requestHeaders
    })
      .then(response => response.json())
      .then(data => {
      this.issues = data.issues;
      this.total = data.total;
      this.maxResults = data.maxResults;
      this.startAt = data.startAt;
    });
  }
  getDescription(issue) {
    if (issue.fields.parent && issue.fields.parent.fields.status &&
      issue.fields.parent.fields.status.description) {
      return issue.fields.parent.fields.status.description;
    }
    return issue.fields.description.content[0].content.text;
  }
  render() {
    return (h(Host, null, this.issues.map((issue) => h("div", { key: issue.id }, h("h5", null, issue.key), h("h5", null, issue.fields.summary), h("p", null, "#", issue.id), issue.fields.assignee
      ? h("p", null, "@ ", issue.fields.assignee.displayName)
      : h("i", null, "Not Assigned"), h("button", { onClick: () => this.issueSelected.emit(issue) }, "View")))));
  }
  static get watchers() { return {
    "account_id": ["watchAccountHandler"],
    "status": ["watchStatusHandler"]
  }; }
};
JiraIssues.style = jiraIssuesCss;

export { JiraIssues as jira_issues };
