import { r as registerInstance, e as createEvent, h } from './index-570f8c12.js';

const jiraTeamCss = ":host{display:block}.item-team{clear:both;border-bottom:1px solid #ccc;margin:10px 0;padding-bottom:10px}.item-team img{margin-right:15px;width:50px;float:left;margin-top:15px}.item-team .pull-right{display:inline-block}";

const JiraTeam = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.userSelected = createEvent(this, "userSelected", 7);
    this.users = [];
  }
  /*
  {
      "self": string,
      "key": string,
      "accountId": string,
      "accountType": string,
      "name": string,
      "avatarUrls": {
        "48x48": string,
        "24x24": string,
        "16x16": string,
        "32x32": string
      },
      "displayName": string,
      "active": boolean
    }
  }*/
  componentWillLoad() {
    return this.loadData();
    /**
     * .then(a => {
      console.log(a);
    }).catch(b => {
      console.error(b);
    }).finally(() => {
      console.info('finished', this.endpoint);
    })
     */
  }
  loadData() {
    const requestHeaders = new Headers();
    requestHeaders.set('Content-Type', 'application/json');
    //requestHeaders.set('Authorization', 'Bearer ' + btoa(unescape(encodeURIComponent(`${this.email}:${this.apitoken}`))))
    //https://bawes.atlassian.net/rest/api/3/users/search
    return fetch(this.endpoint + '/jira/users', {
      headers: requestHeaders
    })
      .then(response => response.json())
      .then(data => {
      this.users = data;
      /*this.users = data.values;
      this.total = data.total;
      this.maxResults = data.maxResults;
      this.startAt = data.startAt;*/
    });
  }
  render() {
    return (h("div", null, this.users.map((user) => h("div", { key: user.accountId, class: "item-team" }, h("img", { src: user.avatarUrls['48x48'] }), h("div", { class: "pull-right" }, h("span", { class: "txt-id" }, "#", user.accountId), user.name && h("h5", { class: "txt-name" }, user.name), h("h4", { class: "txt-display-name" }, user.displayName), h("h5", { class: "txt-job-title" }, user.staff_job_title), h("p", { class: "txt-salary" }, user.staff_salary, " ", user.staff_salary_currency), user.active
      ? h("p", null, "Active")
      : h("p", null, "In-Active"), h("button", { onClick: () => this.userSelected.emit(Object.assign({ action: 'jira-profile' }, user)) }, "View Jira Profile"), h("button", { onClick: () => this.userSelected.emit(Object.assign({ action: 'studenthub-profile' }, user)) }, "View Studenthub Profile"), h("button", { onClick: () => this.userSelected.emit(Object.assign({ action: 'issues' }, user)) }, "View Issues Working on"))))));
  }
};
JiraTeam.style = jiraTeamCss;

export { JiraTeam as jira_team };
