import { r as registerInstance, e as createEvent, h, f as Host } from './index-570f8c12.js';

const plugnStoresCss = ":host{display:block}.item-store{clear:both;border-bottom:1px solid #eee;margin:10px 0;padding-bottom:10px;cursor:pointer}.item-store img{margin-right:15px;width:50px;float:left;height:50px;display:block;overflow:hidden;border-radius:7px}.item-store h5,.item-store p{margin:0 0 5px 0}.item-store .pull-right{display:inline-block}";

const PlugnStores = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.storeSelected = createEvent(this, "storeSelected", 7);
    this.stores = [];
  }
  componentWillLoad() {
    return this.loadData();
  }
  /**
   * load data
   */
  loadData(page = 1) {
    const requestHeaders = new Headers();
    requestHeaders.set('Content-Type', 'application/json');
    return fetch(this.endpoint + '/store?page=' + page, {
      headers: requestHeaders
    })
      .then(response => {
      this.totalPages = parseInt(response.headers.get('X-Pagination-Page-Count'));
      this.totalCount = parseInt(response.headers.get('X-Pagination-Total-Count'));
      this.currentPage = page;
      console.log(this.totalCount, this.totalPages);
      return response.json();
    })
      .then(stores => {
      this.stores = page == 1 ? stores : this.stores.concat(stores);
    });
  }
  /**
   * load next page
   * @returns
   */
  loadMore() {
    if (this.currentPage == this.totalPages) {
      return false;
    }
    this.currentPage++;
    this.loadData(this.currentPage);
  }
  render() {
    return (h(Host, null, h("slot", null), this.stores.map((store) => h("div", { key: store.restaurant_uuid, class: "item-store", onClick: () => this.storeSelected.emit(Object.assign({ action: 'view' }, store)) }, store.logo && h("img", { onError: (e) => { e.target.src = 'https://demo.plugn.store/assets/icon/store.svg'; }, src: "https://res.cloudinary.com/plugn/image/upload/restaurants/" + store.restaurant_uuid + "/logo/" + store.logo }), !store.logo && h("img", { src: "https://demo.plugn.store/assets/icon/store.svg" }), h("div", { class: "pull-right" }, h("h5", null, store.name), h("p", null, store.name_ar), h("a", { href: store.restaurant_domain, target: "_blank" }, store.restaurant_domain)))), this.currentPage < this.totalPages && h("button", { onClick: () => this.loadMore(), class: "btn-load-more" }, "Load more")));
  }
};
PlugnStores.style = plugnStoresCss;

export { PlugnStores as plugn_stores };
