import { r as registerInstance, e as createEvent, h, f as Host } from './index-570f8c12.js';

const walletBalanceCss = ":host{display:block}.item-transaction{clear:both;border-bottom:1px solid #eee;margin:10px 0;padding-bottom:10px;cursor:pointer}.item-transaction img{margin-right:15px;width:50px;float:left;height:50px;display:block;overflow:hidden;border-radius:7px}.item-transaction h5,.item-transaction p{margin:0 0 5px 0}.item-transaction .pull-right{display:inline-block}";

const WalletBalance = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.transactionSelected = createEvent(this, "transactionSelected", 7);
    this.transactions = [];
  }
  componentWillLoad() {
    return this.loadData();
  }
  /**
   * load data
   */
  loadData(page = 1) {
    const requestHeaders = new Headers();
    requestHeaders.set('Content-Type', 'application/json');
    requestHeaders.set('Authorization', 'Bearer ' + this.token);
    return fetch(this.endpoint + '/balance/payable-list?page=' + page, {
      headers: requestHeaders
    })
      .then(response => {
      this.totalPages = parseInt(response.headers.get('X-Pagination-Page-Count'));
      this.totalCount = parseInt(response.headers.get('X-Pagination-Total-Count'));
      this.currentPage = page;
      return response.json();
    })
      .then(transactions => {
      this.transactions = page == 1 ? transactions : this.transactions.concat(transactions);
    });
  }
  /**
   * load next page
   * @returns
   */
  loadMore() {
    if (this.currentPage == this.totalPages) {
      return false;
    }
    this.currentPage++;
    this.loadData(this.currentPage);
  }
  /**
   * render view
   * @returns
   */
  render() {
    return (h(Host, null, h("slot", null), h("table", null, h("thead", null, h("tr", null, h("th", null, "Date"), h("th", null, "Detail"), h("th", null, "Debit"), h("th", null, "Credit"), h("th", null, "Balance"))), h("tbody", null, this.transactions.map((transaction) => h("tr", { key: transaction.balance_transaction_uuid, class: "item-transaction", onClick: () => this.transactionSelected.emit(Object.assign({ action: 'view' }, transaction)) }, h("td", null, transaction.transaction_datetime), h("td", null, transaction.data), h("td", null, transaction.amount < 0 ? 0 - transaction.amount : null), h("td", null, transaction.amount > 0 ? transaction.amount : null), h("td", null, transaction.balance))))), this.currentPage < this.totalPages && h("button", { onClick: () => this.loadMore(), class: "btn-load-more" }, "Load more")));
  }
};
WalletBalance.style = walletBalanceCss;

export { WalletBalance as wallet_balance };
