import { r as registerInstance, e as createEvent, h, f as Host } from './index-570f8c12.js';

const walletSendMoneyCss = ":host{display:block}";

const WalletSendMoney = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.transactionError = createEvent(this, "transactionError", 7);
    this.transactionComplete = createEvent(this, "transactionComplete", 7);
  }
  handleSubmit(event) {
    event.preventDefault();
    console.log(event);
    if (this.amount < 0.001) {
      //console.error();
      this.transactionError.emit({
        message: 'Amount can not be less than 0.001'
      });
    }
    const requestHeaders = new Headers();
    requestHeaders.set('Content-Type', 'application/json; charset=UTF-8');
    requestHeaders.set('Authorization', 'Bearer ' + this.token);
    return fetch(this.endpoint + '/balance/pay-by-wallet', {
      headers: requestHeaders,
      method: 'PATCH',
      body: JSON.stringify({
        email: this.email,
        amount: this.amount
      })
    })
      .then(response => {
      return response.json();
    })
      .then(response => {
      if (response.operation == 'success') {
        this.transactionComplete.emit({ 'email': this.email, 'amount': this.amount });
      }
      else {
        this.transactionError.emit(response);
      }
    });
  }
  handleEmailChange(event) {
    console.log(event);
    this.email = event.target.value;
  }
  handleAmountChange(event) {
    console.log(event);
    this.amount = event.target.value;
  }
  render() {
    return (h(Host, null, h("slot", null), h("form", { onSubmit: (e) => this.handleSubmit(e) }, h("label", null, "Email of recipient:", h("input", { type: "email", required: true, value: this.email, onInput: (event) => this.handleEmailChange(event) })), h("label", null, "Amount:", h("input", { type: "number", required: true, min: "1", value: this.amount, onInput: (event) => this.handleAmountChange(event) })), h("input", { type: "submit", value: "Submit" }))));
  }
};
WalletSendMoney.style = walletSendMoneyCss;

export { WalletSendMoney as wallet_send_money };
